@@ -6,13 +6,19 @@ from __future__ import annotations
 import logging
 from datetime import datetime
 from pathlib import Path
-from typing import Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional, Tuple
 
 import numpy as np
 from numpy.typing import ArrayLike
 
 from .. import get_iso_timestamp, units_of_length, units_of_time, ureg
-from . import calculate_origin, create_attributes, set_dependency, write_compressed_copy
+from . import (
+    calculate_origin,
+    create_attributes,
+    set_dependency,
+    set_instrument_name,
+    write_compressed_copy,
+)
 
 # from hdf5plugin import Bitshuffle   # noqa: F401
 
@@ -42,7 +48,9 @@ def write_NXentry(nxsfile: h5py.File, definition: str = "NXmx") -> h5py.Group:
 
     # Start writing the NeXus tree with NXentry at the top level
     nxentry = nxsfile.require_group("entry")
-    create_attributes(nxentry, ("NX_class", "default"), ("NXentry", "data"))
+    create_attributes(
+        nxentry, ("NX_class", "default", "version"), ("NXentry", "data", "1.0")
+    )
 
     # Application definition: /entry/definition
     nxentry.create_dataset("definition", data=np.string_(definition))
@@ -176,6 +184,7 @@ def write_NXsample(
     osc_scan: Dict[str, ArrayLike],
     transl_scan: Dict[str, ArrayLike] = None,
     sample_depends_on: str = None,
+    sample_details: Dict[str, Any] = None,
 ):
     """
     Write NXsample group at /entry/sample.
@@ -187,6 +196,7 @@ def write_NXsample(
         osc_scan (Dict[str, ArrayLike]): Rotation scan. If writing events, this is just a (start, end) tuple.
         transl_scan (Dict[str, ArrayLike], optional): Scan along the xy axes at sample. Defaults to None.
         sample_depends_on (str): Axis on which the sample depends on. If absent, the depends_on field will be set to the last axis listed in the goniometer. Defaults to None.
+        sample_details (Dict[str, Any]): General information about the sample, eg. name, temperature.
     """
     NXclass_logger.info("Start writing NXsample and NXtransformations.")
     # Create NXsample group, unless it already exists, in which case just open it.
@@ -311,13 +321,19 @@ def write_NXsample(
     try:
         nxsample["beam"] = nxsfile["/entry/instrument/beam"]
     except KeyError:
-        pass
+        NXclass_logger.debug(
+            "No NXbeam group found elsewhere in the NeXus file." "No link written."
+        )
+
+    if sample_details:
+        for k, v in sample_details.items():
+            if type(v) is str:
+                v = np.string_(v)
+            nxsample.create_dataset(k, data=v)
 
 
 # NXinstrument
-def write_NXinstrument(
-    nxsfile: h5py.File, beam: Dict, attenuator: Dict, beamline_n: str
-):
+def write_NXinstrument(nxsfile: h5py.File, beam: Dict, attenuator: Dict, source: Dict):
     """
     Write NXinstrument group at /entry/instrument.
 
@@ -325,7 +341,7 @@ def write_NXinstrument(
         nxsfile (h5py.File): NeXus file handle.
         beam (Dict):Dictionary with beam information, mainly wavelength and flux.
         attenuator (Dict): Dictionary containing transmission.
-        beamline_n (str): Identifies which beamline the data was collected on.
+        source (Dict): Dictionary containing the facility information.
     """
     NXclass_logger.info("Start writing NXinstrument.")
     # Create NXinstrument group, unless it already exists, in which case just open it.
@@ -337,11 +353,14 @@ def write_NXinstrument(
     )
 
     # Write /name field and relative attribute
-    NXclass_logger.info(f"DLS beamline {beamline_n}")
-    nxinstrument.create_dataset(
-        "name", data=np.string_("DIAMOND BEAMLINE " + beamline_n)
+    NXclass_logger.info(f"{source['short_name']} {source['beamline_name']}")
+    name_str = set_instrument_name(source)
+    nxinstrument.create_dataset("name", data=np.string_(name_str))
+    create_attributes(
+        nxinstrument["name"],
+        ("short_name",),
+        (f"{source['short_name']} {source['beamline_name']}",),
     )
-    create_attributes(nxinstrument["name"], ("short_name",), ("DLS " + beamline_n,))
 
     NXclass_logger.info("Write NXattenuator and NXbeam.")
     # Write NXattenuator group: entry/instrument/attenuator
