@@ -2,8 +2,10 @@
 Tools to get the information stored inside the _meta.h5 file and overwrite the phil scope.
 """
 
+from __future__ import annotations
+
 import logging
-from typing import Any, List
+from typing import Any, Dict, List
 
 import h5py
 
@@ -15,15 +17,18 @@ overwrite_logger = logging.getLogger("nexgen.MetaReader")
 overwrite_logger.setLevel(logging.DEBUG)
 
 
-def overwrite_beam(meta_file: h5py.File, name: str, beam: Any):
+def overwrite_beam(meta_file: h5py.File, name: str, beam: Dict | Any):
     """
     Looks for the wavelength value in the _meta.h5 file.
     If found, it overwrites the value that was parsed from the command line.
 
     Args:
-        meta_file:  _meta.h5 file.
-        name:       Detector description.
-        beam:       Scope extract or dictionary defining the beam.
+        meta_file (h5py.File): Handle for _meta.h5 file.
+        name (str): Detector description.
+        beam (Dict | Any): Scope extract or dictionary defining the beam.
+
+    Raises:
+        ValueError: If an invalid detector description is passed. Allowed detectors for this function: Eiger.
     """
     if "eiger" in name.lower():
         meta = DectrisMetafile(meta_file)
@@ -46,17 +51,21 @@ def overwrite_beam(meta_file: h5py.File, name: str, beam: Any):
 
 
 def overwrite_detector(
-    meta_file: h5py.File, detector: Any, ignore: List = None
+    meta_file: h5py.File, detector: Dict | Any, ignore: List = None
 ) -> List:
     """
     Looks through the _meta.h5 file for informtion relating to NXdetector.
 
     Args:
-        meta_file:  _meta.h5 file.
-        detector:   Scope extract or dictionary defining the detector.
-        ignore:     List of datasets that should not be overwritten by the meta file.
+        meta_file (h5py.File): Handle for _meta.h5 file.
+        detector (Dict | Any): Scope extract or dictionary defining the detector.
+        ignore (List, optional): List of datasets that should not be overwritten by the meta file. Defaults to None.
+
+    Raises:
+        ValueError: If an invalid detector description is passed. Allowed detectors for this function: Eiger, Tristan.
+
     Returns:
-        link_list:  A list of elements to be linked instead of copied in the NeXus file.
+        link_list (List): A list of elements to be linked instead of copied in the NeXus file.
     """
     new_values = {}
     link_list = [[], []]
@@ -154,3 +163,83 @@ def overwrite_detector(
             except KeyError:
                 detector.__inject__(k, v)
     return link_list
+
+
+def update_goniometer(meta_file: h5py.File, goniometer: Dict):
+    """
+    Read the axes values from the config/ dataset in the meta file and update the goniometer.
+
+    Args:
+        meta_file (h5py.File): Handle to Dectris-shaped meta.h5 file.
+        goniometer (Dict): Dictionary containing all the goniometer axes information.
+    """
+    overwrite_logger.info(
+        "Get goniometer axes values from meta file for Eiger detector."
+    )
+    meta = DectrisMetafile(meta_file)
+
+    if meta.hasConfig is True:
+        config = meta.read_config_dset()
+        num = meta.get_number_of_images()
+
+        goniometer["starts"] = []
+        goniometer["ends"] = []
+        goniometer["increments"] = []
+
+        for ax in goniometer["axes"]:
+            if f"{ax}_start" in config.keys():
+                s = config[f"{ax}_start"]
+                goniometer["starts"].append(s)
+                overwrite_logger.info(f"Start value for axis {ax}: {s}.")
+                inc = (
+                    config[f"{ax}_increment"]
+                    if f"{ax}_increment" in config.keys()
+                    else 0.0
+                )
+                goniometer["increments"].append(inc)
+                overwrite_logger.info(f"Increment value for axis {ax}: {inc}.")
+                e = s + inc * num
+                goniometer["ends"].append(e)
+                overwrite_logger.info(f"End value for axis {ax}: {e}.")
+            else:
+                goniometer["starts"].append(0.0)
+                goniometer["ends"].append(0.0)
+                goniometer["increments"].append(0.0)
+                overwrite_logger.info(f"Axis {ax} not in meta file, values set to 0.0.")
+    else:
+        overwrite_logger.warning(
+            "No config/ dataset found in meta file. Goniometer axes value couldn't be updated from here."
+        )
+        return
+
+
+def update_detector_axes(meta_file: h5py.File, detector: Dict):
+    """
+    Read the axes values from the config/ dataset in the meta file and update the detector.
+
+    Args:
+        meta_file (h5py.File): Handle to Dectris-shaped meta.h5 file.
+        detector (Dict): Dictionary containing all the detector information.
+    """
+    overwrite_logger.info("Get detector axes values from meta file for Eiger detector.")
+    meta = DectrisMetafile(meta_file)
+
+    if meta.hasConfig is True:
+        config = meta.read_config_dset()
+        dist = units_of_length(meta.get_detector_distance())
+
+        detector["starts"] = []
+        detector["ends"] = []
+
+        # First look for two_theta, then append det_z
+        # For the moment, assume the detector doesn't move.
+        for ax in detector["axes"]:
+            if f"{ax}_start" in config.keys():
+                s = config[f"{ax}_start"]
+                detector["starts"].append(s)
+                overwrite_logger.info(f"Position of axis {ax}: {s}.")
+
+        detector["starts"].append(dist.to("mm").magnitude)
+        overwrite_logger.info(f"Position of axis det_z: {dist.to('mm')}.")
+
+        detector["ends"] = detector["starts"]
